@@ -36,4 +36,14 @@ globalVariables(c(':=',
                   'y75',
                   'y95',
                   'ymax',
-                  'ymin'))
+                  'ymin',
+                  'Count',
+                  'Denominator',
+                  'EngVal',
+                  'IndicatorName',
+                  'LCI',
+                  'ParentAreaCode',
+                  'Polarity',
+                  'Timeperiod',
+                  'UCI',
+                  'Value'))
